@@ -1,4 +1,4 @@
-#! /bin/sh
+#   This file must be sourced inside (ba)sh using: .
 #
 #   ld_lib_path.sh
 #
@@ -15,101 +15,63 @@
 #
 #   This library is free software; you can redistribute it and/or
 #   modify it under the terms of the GNU General Public License
-#   as published by the Free Software Foundation; either version 2
+#   as published by the Free Software Foundation; either version 3
 #   of the License, or (at your option) any later version.
 #   
 #   You should have received a copy of the GNU General Public
-#   License along with this library; see the file COPYING.LIB.
+#   License along with this library; see the file COPYING.
 #   If not, write to the Free Software Foundation,
 #   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 #
 
+# The modern version of this file basically expects you to execute it
+# inside GNUstep.sh.  If not, you need to have at least the
+# GNUSTEP_MAKEFILES, GNUSTEP_HOST_*, GNUSTEP_SYSTEM_LIBRARIES,
+# GNUSTEP_LOCAL_LIBRARIES, etc.  GNUSTEP_SYSTEM_LIBRARY,
+# GNUSTEP_LOCAL_LIBRARY, etc. variables defined.
+
+# FIXME/TODO: Update all callers to source GNUstep.sh and not this file.
+
 # This file is sourced.  This means extra care is needed when changing
 # it.  Please read the comments on GNUstep.sh.in before touching it.
 
-# The first (and only) parameter to this script is the canonical
-# operating system name.
-
-host_os=$GNUSTEP_HOST_OS
-
-if [ -z "$host_os" ]; then
-  host_os=$1
-fi
-
-
-old_IFS="$IFS"
-IFS=:
 lib_paths=
 fw_paths=
-for dir in $GNUSTEP_PATHLIST; do
 
-  # prepare the path_fragment for libraries and this dir
-  if [ -z "$GNUSTEP_FLATTENED" ]; then
-    path_fragment="$dir/Library/Libraries/$GNUSTEP_HOST_CPU/$GNUSTEP_HOST_OS/$LIBRARY_COMBO:$dir/Library/Libraries/$GNUSTEP_HOST_CPU/$GNUSTEP_HOST_OS"
-  else
-    path_fragment="$dir/Library/Libraries"
-  fi
+# Determine the library paths
+GNUSTEP_LIBRARIES_PATHLIST=`$GNUSTEP_MAKEFILES/print_unique_pathlist.sh "$GNUSTEP_USER_LIBRARIES" "$GNUSTEP_LOCAL_LIBRARIES" "$GNUSTEP_NETWORK_LIBRARIES" "$GNUSTEP_SYSTEM_LIBRARIES" $fixup_paths`
 
-  # Append the path_fragment to lib_paths
-  if [ -z "$lib_paths" ]; then
-    lib_paths="$path_fragment"
-  else
-    lib_paths="$lib_paths:$path_fragment"
-  fi
-
-  # prepare the path_fragment for frameworks and this dir
-  path_fragment="$dir/Library/Frameworks"
-
-  # Append the path_fragment to fw_paths
-  if [ -z "$fw_paths" ]; then
-    fw_paths="$path_fragment"
-  else
-    fw_paths="$fw_paths:$path_fragment"
-  fi
-
-  unset path_fragment
-
-done
-IFS="$old_IFS"
-unset old_IFS
-unset dir
-
-
-if [ -n "$additional_library_paths" ]; then
+if [ "$GNUSTEP_IS_FLATTENED" = "yes" ]; then
+  lib_paths="$GNUSTEP_LIBRARIES_PATHLIST"
+else
   old_IFS="$IFS"
-  IFS=" 
-"
-  additional=""
-  for dir in $additional_library_paths; do
-    additional="${additional}${dir}:"
-  done
-  unset dir
+  IFS=:
+    for dir in $GNUSTEP_LIBRARIES_PATHLIST; do
 
-  lib_paths="${additional}${lib_paths}"
+      # prepare the path_fragment for libraries and this dir
+      path_fragment="$dir/$GNUSTEP_HOST_CPU/$GNUSTEP_HOST_OS/$LIBRARY_COMBO:$dir/$GNUSTEP_HOST_CPU/$GNUSTEP_HOST_OS"
 
-  unset additional
+      # Append the path_fragment to lib_paths
+      if [ -z "$lib_paths" ]; then
+        lib_paths="$path_fragment"
+      else
+        lib_paths="$lib_paths:$path_fragment"
+      fi
+
+      unset path_fragment
+    done
   IFS="$old_IFS"
   unset old_IFS
-fi
-
-if [ -n "$additional_framework_paths" ]; then
-  old_IFS="$IFS"
-  IFS="
-"
-  additional=""
-  for dir in $additional_framework_paths; do
-    additional="${additional}${dir}:"
-  done
   unset dir
-
-  fw_paths="${additional}${fw_paths}"
-
-  unset additional
-  IFS="$old_IFS"
-  unset old_IFS
 fi
 
-case "$host_os" in
+unset GNUSTEP_LIBRARIES_PATHLIST
+
+# Determine the framework paths
+fw_paths=`$GNUSTEP_MAKEFILES/print_unique_pathlist.sh "$GNUSTEP_USER_LIBRARY/Frameworks" "$GNUSTEP_LOCAL_LIBRARY/Frameworks" "$GNUSTEP_NETWORK_LIBRARY/Frameworks" "$GNUSTEP_SYSTEM_LIBRARY/Frameworks" $fixup_paths`
+
+
+case "$GNUSTEP_HOST_OS" in
 
   *nextstep4*)
     if [ -z "$DYLD_LIBRARY_PATH" ]; then
@@ -193,7 +155,6 @@ case "$host_os" in
 
 esac
 
-unset host_os
 unset lib_paths
 unset fw_paths
 
